Get all the files defined by a catalogue
get_files.RdThis function takes a catalogue of ERA5 data (typically obtained from era5()
and filtered with set_date_range()) and returns the corresponding file paths
on gadi's filesystem.
Arguments
- catalogue
A data.table containing ERA5 catalogue information. Typically obtained by subsetting the output of
era5()and applyingset_date_range().
Value
A data.table with columns:
variable: The ERA5 variable nameaggregation: The temporal aggregation (e.g., "monthly", "hourly")range_start: Start date of the requested rangerange_end: End date of the requested rangefiles: A list column containing character vectors of file paths for each combination of variable, aggregation, and date range. Files that don't exist will beNA.
Examples
if (FALSE) { # \dontrun{
# Get catalogue and filter for specific variable and dates
catalogue <- era5() |>
subset(variable == "2t") |>
set_date_range("2020-01-01", "2020-12-31") |>
get_files(catalogue)
} # }